#!/bin/bash
#
# vim:sw=2:sts=2:ts=2:set expandtab:
#
# This script is based on C-A's script set for compiling gstreamer for broadcom.
# Change the variables below to build for another target.
# Build with ./build-gstreamer.sh release
#
# The built gstreamer can be run on device with:
# export GST_INSTALL=$PWD/
# export GST_PLUGIN_SYSTEM_PATH=$GST_INSTALL/lib/gstreamer-0.10/
# export LD_LIBRARY_PATH=$GST_INSTALL/lib/:$LD_LIBRARY_PATH
# export GST_PLUGIN_SCANNER=$GST_INSTALL/libexec/gstreamer-0.10/gst-plugin-scanner
# /usr/local/bin/directfb/1.7/rundfb.sh ./bin/gst-launch-0.10 playbin2 uri=file:///video.mp4
#

BUILD_GST_1_X=1
SOFTWARE_VP9=0
# FIXME: toggle software decoders like h264/vp9 on/off depending on this
SOFTWARE_DECODERS=0

TARGET=
TVSDK_DIR=
version=release
fetch_only=0

print_usage() {
    cat << EOF
Usage: $0 [options]
    -h, --help              Print this help and exit
    -r, --release           Build release GStreamer and deps (default)
    -d, --debug             Build debug GStreamer and deps
    -n, --fetch-only        Only fetch or unpack sources,
                                do not build anything.
    --software-vp9          Build VP9 software decoder (GStreamer 1.x only)
    -t <T>, --target=<T>    Select target device. MANDATORY.
    -s <DIR> --sdk <DIR>    tvsdk directory, useful for some targets to get compiling options
Targets available:
EOF
ls targets/target-* | sed 's/targets\/target-//' - | sed 's/.sh//' -
}

set_terminal_caption() {
    echo -ne "\033]0;Building $1 ...\007"
}

SHORTOPTS="hrdnt:s:"
LONGOPTS="help,release,debug,fetch-only,software-vp9,target:,sdk:"

OPTS=$(getopt -o $SHORTOPTS --long $LONGOPTS -n "${progname:-}" -- "$@")
eval set -- "$OPTS"

while [ $# -gt 0 ]; do
    case $1 in
        -h|--help) print_usage; exit 0;;
        -r|--release) version="release"; shift ;;
        -d|--debug) version="debug"; shift;;
        -n|--fetch-only) fetch_only=1; shift;;
        --software-vp9) SOFTWARE_VP9=1; shift;;
        -t|--target) TARGET=$2; shift 2 ;;
        -s|--sdk) TVSDK_DIR=$2; shift 2 ;;
        --) shift; break;;
        *) echo "Invalid option $1"; print_usage; exit 1;;
    esac
done

if [ ${BUILD_GST_1_X} -eq 1 ]; then
    echo "Building GST 1.x"
fi

if ! [ -f targets/target-$TARGET.sh ]; then
    echo "No target selected"
    print_usage
    exit 1
fi

set -ex

GMP=gmp-4.2.1
NETTLE=nettle-2.7.1
GNUTLS=gnutls-3.3.9
LIBFFI=libffi-3.0.13
GETTEXT=gettext-0.19.8
SQLITE=sqlite-autoconf-3150100
GLIB=glib-2.36.3
GLIB_NETWORKING=glib-networking-2.36.2
ORC=orc-0.4.26
LIBSOUP=libsoup-2.42.2
LIBXML2=libxml2-2.8.0

GSTREAMER_1_X=gstreamer-1.6.3
GST_PLUGINS_BASE_1_X=gst-plugins-base-1.6.3
GST_PLUGINS_GOOD_1_X=gst-plugins-good-1.6.3
GST_PLUGINS_BAD_1_X=gst-plugins-bad-1.4.5

. targets/target-$TARGET.sh

top_dir=$(dirname $(readlink -f $0))

build_dir=$top_dir/build-$TARGET
top_source_dir=$build_dir/sources
archives_dir=$top_dir/archives

GSTROOT=$build_dir/output/gstreamer-${version}
export ACLOCAL_PATH=${GSTROOT}/share/aclocal

PKG_CONFIG_PATH=${GSTROOT}/lib/pkgconfig
PKG_CONFIG_PATH+=":${ZLIB_PATH}/lib/pkgconfig"
export PKG_CONFIG_PATH=${PKG_CONFIG_PATH}
export PKG_CONFIG_LIBDIR=""

export PATH=$TOOLCHAIN/bin:$PATH

EXTRA_FLAGS=
if [ "$version" = "release" ]; then
    EXTRA_FLAGS="-O2"
else
    EXTRA_FLAGS="-O0 -g"
fi

export CFLAGS="$CFLAGS $EXTRA_FLAGS"
export CXXFLAGS="$CXXFLAGS $EXTRA_FLAGS"
export CPPFLAGS="$CPPFLAGS $EXTRA_FLAGS"
export LDFLAGS="$LDFLAGS -Wl,-rpath=${GSTROOT}/lib -Wl,-rpath=${ZLIB_PATH}/lib"

AUTOCONF_FLAGS="--host=${HOST} --prefix=${GSTROOT} --libdir=${GSTROOT}/lib --disable-static"
GSTREAMER_FLAGS="--enable-gtk-doc-html=no --enable-gtk-doc=no --disable-examples --disable-x --disable-xvideo --disable-nls"

mkdir -p $build_dir/sources/gstreamer/$version
cd $build_dir/sources/gstreamer/$version
source_dir=$(pwd)

#libxml2
if ! [ -d $LIBXML2 ]; then
    set_terminal_caption libxml2
    tar xf ${archives_dir}/${LIBXML2}.tar.gz

    cd libxml2*
    if [ $fetch_only -eq 0 ]; then
        ./configure ${AUTOCONF_FLAGS} --with-python=no
        make -j 10
        make install
    fi
    cd $source_dir
fi

#libffi
if ! [ -d $LIBFFI ]; then
    set_terminal_caption libffi
    tar xf ${archives_dir}/${LIBFFI}.tar.gz
    cd $LIBFFI
    if [ $fetch_only -eq 0 ]; then
        ./configure ${AUTOCONF_FLAGS}
        make -j 10
        make install
        # HACK! 64bit ffi build will not respect --libdir, move libs and fix libtool post-install.
        if [ -d ${GSTROOT}/lib64 ]; then
            mv ${GSTROOT}/lib64/* ${GSTROOT}/lib
            sed -i 's|lib/../lib64|lib|' ${GSTROOT}/lib/libffi.la
        fi
    fi
    cd $source_dir
fi

#gettext
if ! [ -d $GETTEXT ]; then
    set_terminal_caption gettext
    tar xf ${archives_dir}/${GETTEXT}.tar.xz
    cd $GETTEXT
    if [ $fetch_only -eq 0 ]; then
        ./configure ${AUTOCONF_FLAGS}
        make -C gettext-runtime/intl -j 10
        make -C gettext-runtime/intl install
    fi
    cd $source_dir
fi

#glib
if ! [ -d $GLIB ]; then
(
    set_terminal_caption glib
    tar xf ${archives_dir}/${GLIB}.tar.xz

    cd ${GLIB}

    if [ "$ENABLE_GLIB_M4_HACK" = "1" ]; then
        #hack
        rm m4macros/glib-gettext.m4
        touch m4macros/glib-gettext.m4
    fi

    if [ $fetch_only -eq 0 ]; then
        export glib_cv_stack_grows=no
        export glib_cv_uscore=no
        export ac_cv_func_posix_getpwuid_r=yes
        export ac_cv_func_posix_getgrgid_r=yes
        export glib_cv_long_long_format=ll
        export ac_cv_func_printf_unix98=yes
        export ac_cv_func_vsnprintf_c99=yes

        # Without adding GSTROOT to flags, building will fail for MIPS targets on missing gettext
        EXTRA_FLAGS="$EXTRA_FLAGS -L${GSTROOT}/lib -I${GSTROOT}/include/"
        export CFLAGS="$CFLAGS $EXTRA_FLAGS"
        export CXXFLAGS="$CXXFLAGS $EXTRA_FLAGS"
        export CPPFLAGS="$CPPFLAGS $EXTRA_FLAGS"

        # Without adding the local dirs to the LDFLAGS, building will fail on Debian/Ubuntu, but not on Fedora
        export LDFLAGS=" -Wl,-rpath=${PWD}/glib/.libs  -Wl,-rpath=${PWD}/gio/.libs  -Wl,-rpath=${PWD}/gmodule/.libs  -Wl,-rpath=${PWD}/gthread/.libs  -Wl,-rpath=${PWD}/gobject/.libs $LDFLAGS"
        ./configure ${AUTOCONF_FLAGS} --disable-gtk-doc --disable-modular-tests --disable-libmount --with-pcre=internal
        make -j 10
        make install
    fi
    cd $source_dir
)
fi

#gmp
if ! [ -d ${GMP} ]; then
    set_terminal_caption gmp
    tar xf ${archives_dir}/${GMP}.tar.bz2
    cd ${GMP}
    patch -Np1 -i ${archives_dir}/gmp-4.2.1-mips-asm-gcc-4.4.patch
    patch -Np1 -i ${archives_dir}/010-mpn-arm-udiv_asm.patch
    if [ $fetch_only -eq 0 ]; then
        LDFLAGS="$LDFLAGS -Wl,-z,noexecstack" ./configure ${AUTOCONF_FLAGS}
        make -j 10
        make install
    fi
    cd $source_dir
fi

#nettle
if ! [ -d ${NETTLE} ]; then
    set_terminal_caption nettle
    tar xf ${archives_dir}/${NETTLE}.tar.gz
    cd ${NETTLE}
    if [ $fetch_only -eq 0 ]; then
        # Need to enable static, otherwise it wont build:
        ./configure ${AUTOCONF_FLAGS} --enable-public-key --enable-static --disable-openssl --disable-documentation --with-include-path=${GSTROOT}/include --with-lib-path=${GSTROOT}/lib
        make -j 10
        sed -i '/^install-here/ s/install-static//' Makefile
        make install
    fi
    cd $source_dir
fi

#gnutls
if ! [ -d ${GNUTLS} ]; then
    set_terminal_caption gnutls
    tar xf ${archives_dir}/${GNUTLS}.tar.xz
    cd ${GNUTLS}
    if [ $fetch_only -eq 0 ]; then
        GMP_LIBS="-L${GSTROOT}/lib -lgmp" GMP_CFLAGS=-I${GSTROOT}/include ./configure ${AUTOCONF_FLAGS} --enable-local-libopts --disable-openssl-compatibility
        make -j 10
        make install
    fi
    cd $source_dir
fi

#glib-networking
if ! [ -d ${GLIB_NETWORKING} ]; then
    set_terminal_caption glib-networking
    tar xf ${archives_dir}/${GLIB_NETWORKING}.tar.xz

    cd ${GLIB_NETWORKING}
    if [ $fetch_only -eq 0 ]; then
        CPPFLAGS=-I${GSTROOT}/include ./configure ${AUTOCONF_FLAGS} --with-ca-certificates=/dev/null
        make -j 10
        make install
    fi
    cd $source_dir
fi

#orc, replaces liboil
if ! [ -d ${ORC} ]; then
    set_terminal_caption liboil
    tar xf ${archives_dir}/${ORC}.tar.xz

    cd ${ORC}
    if [ $fetch_only -eq 0 ]; then
        ./configure ${AUTOCONF_FLAGS} --disable-gtk-doc
        make -j 10
        make install
    fi
    cd $source_dir
fi

#sqlite
if ! [ -d $SQLITE ]; then
    set_terminal_caption sqlite
    tar xf ${archives_dir}/${SQLITE}.tar.gz
    cd $SQLITE
#    patch -p1 <${archives_dir}/${SQLITE}-posix-fallocate.patch
    if [ $fetch_only -eq 0 ]; then
        ./configure ${AUTOCONF_FLAGS}
        make -j 10
        make install
    fi
    cd $source_dir
fi

#libsoup
if ! [ -d ${LIBSOUP} ]; then
(
    set_terminal_caption libsoup
    tar xf ${archives_dir}/${LIBSOUP}.tar.xz

    cd ${LIBSOUP}
    if [ $fetch_only -eq 0 ]; then
        ./configure ${AUTOCONF_FLAGS} --disable-gtk-doc --disable-nls --without-gssapi
        make -j 10
        make install
    fi
    cd $source_dir
)
fi


if [ ${BUILD_GST_1_X} -eq 1 ]; then

    if [ ${SOFTWARE_VP9} -eq 1 ]; then

        #libvpx
        if ! [ -d libvpx ]; then
            set_terminal_caption libvpx
            git clone https://github.com/webmproject/libvpx.git

            cd libvpx
            git checkout  v1.5.0

            if [ ${HOST%%-*} == "arm" ]; then
                LIBVPX_TARGET=armv7-linux-gcc
                LIBVPX_HOST=arm-none-linux-gnueabi
            elif [ ${HOST%%-*} == "mipsel" ]; then
                LIBVPX_TARGET=mips32-linux-gcc
                LIBVPX_HOST=set_the_right_cross_host_for_libvpn
            elif [ ${HOST%%-*} == "x86_64" ]; then
                LIBVPX_TARGET=x86_64-linux-gcc
                LIBVPX_HOST=set_the_right_cross_host_for_libvpn
            elif [ ${HOST%%-*} == "x86" ]; then
                LIBVPX_TARGET=x86-linux-gcc
                LIBVPX_HOST=set_the_right_cross_host_for_libvpn
            else
                echo "Processor not supported. Can not enable software VP9"
                exit 1
            fi

            mkdir bin && true
            ln -sf  $TOOLCHAIN/bin/${HOST}-ar     bin/${LIBVPX_HOST}-ar
            ln -sf  $TOOLCHAIN/bin/${HOST}-as     bin/${LIBVPX_HOST}-as
            ln -sf  $TOOLCHAIN/bin/${HOST}-g++    bin/${LIBVPX_HOST}-g++
            ln -sf  $TOOLCHAIN/bin/${HOST}-gcc    bin/${LIBVPX_HOST}-gcc
            ln -sf  $TOOLCHAIN/bin/${HOST}-ld     bin/${LIBVPX_HOST}-ld
            ln -sf  $TOOLCHAIN/bin/${HOST}-strip  bin/${LIBVPX_HOST}-strip

            if [ $fetch_only -eq 0 ]; then
                export PATH=$PWD/bin:$PATH
                ./configure   \
                    --target=$LIBVPX_TARGET \
                    --enable-vp9  \
                    --enable-runtime-cpu-detect \
                    --enable-ccache \
                    --enable-thumb  \
                    --enable-pic    \
                    --disable-examples --disable-docs  \
                    --prefix=${GSTROOT} --libdir=${GSTROOT}/lib
                make -j 10
                make install
            fi
            cd $source_dir
        fi

        #libwebm
        if ! [ -d libwebm ]; then
            set_terminal_caption libwebm
            git clone https://chromium.googlesource.com/webm/libwebm

            cd libwebm
            git checkout  libwebm-1.0.0.27
            if [ $fetch_only -eq 0 ]; then
                CXX=$TOOLCHAIN/bin/${HOST}-g++  make  -f Makefile.unix  libwebm.so
                CXX=$TOOLCHAIN/bin/${HOST}-g++  make  -f Makefile.unix  libwebm.a
                cp -v  *.{h,hpp}  ~/code/gstreamer-builder/build-BCM-7252S/output/gstreamer-release/include
                cp -v  libwebm.a libwebm.so  ~/code/gstreamer-builder/build-BCM-7252S/output/gstreamer-release/lib/
            fi
            cd $source_dir
        fi

    fi


    #gstreamer
    if ! [ -d ${GSTREAMER_1_X} ]; then
        set_terminal_caption gstreamer1
        tar xf ${archives_dir}/${GSTREAMER_1_X}.tar.xz

        cd ${GSTREAMER_1_X}
        if [ "$GSTREAMER_1_X" == "gstreamer-1.6.4" ]; then
          patch -Np1 -i ${archives_dir}/gstreamer-1.6.4-gstclock-fixed-dangling-timer.patch
          patch -Np1 -i ${archives_dir}/gstreamer-1.6.4-gstclock-fixed-unschedule-fail.patch
          patch -Np1 -i ${archives_dir}/gstreamer-1.6.4-gstclock-unschedule-timer-sync.patch
        fi
        if [ $fetch_only -eq 0 ]; then
            ./configure ${AUTOCONF_FLAGS} ${GSTREAMER_FLAGS} --disable-tests --disable-failing-tests --disable-benchmarks --disable-check --disable-nls
            make -j 10
            make install
        fi
        cd $source_dir
    fi

    #gst-plugins-base
    if ! [ -d ${GST_PLUGINS_BASE_1_X} ]; then
        set_terminal_caption gst-plugins-base1
        tar xf ${archives_dir}/${GST_PLUGINS_BASE_1_X}.tar.xz

        cd ${GST_PLUGINS_BASE_1_X}
        if [ $fetch_only -eq 0 ]; then
            ./configure ${AUTOCONF_FLAGS} ${GSTREAMER_FLAGS} ${GST_PLUGINS_BASE_PLATFORM_FLAGS} \
            --disable-adder \
            --disable-app \
            --disable-audiorate \
            --disable-audiotestsrc \
            --disable-encoding \
            --disable-videoconvert \
            --disable-gio \
            --disable-playback \
            --disable-tcp \
            --disable-videotestsrc \
            --disable-videorate \
            --disable-videoscale \
            --disable-libvisual \
            --disable-pango \
            --disable-theora \
            --disable-vorbis \
            --disable-gio_unix_2_0
            make -j 10
            make install
        fi
        cd $source_dir
    fi


    #gst-plugins-good
    if ! [ -d ${GST_PLUGINS_GOOD_1_X} ]; then
        set_terminal_caption gst-plugins-good1
        tar xf ${archives_dir}/${GST_PLUGINS_GOOD_1_X}.tar.xz

        cd ${GST_PLUGINS_GOOD_1_X}
        
        if [ "$GST_PLUGINS_GOOD_1_X" == "gst-plugins-good-1.6.4" ]; then
            patch -Np1 -i ${archives_dir}/gst-plugins-good-1.6.4_fix_souphttpsrc_seek_issue.patch
        fi
        
        if [ $fetch_only -eq 0 ]; then
            ./configure ${AUTOCONF_FLAGS} ${GSTREAMER_FLAGS} \
            --disable-alpha \
            --disable-apetag \
            --disable-audiofx \
            --disable-auparse \
            --disable-autodetect \
            --disable-avi \
            --disable-cutter \
            --disable-debugutils \
            --disable-deinterlace \
            --disable-dtmf \
            --disable-effectv \
            --disable-equalizer \
            --disable-flv \
            --disable-flx \
            --disable-goom \
            --disable-goom2k1 \
            --disable-icydemux \
            --disable-imagefreeze \
            --disable-interleave \
            --disable-law \
            --disable-level \
            --disable-monoscope \
            --disable-multifile \
            --disable-multipart \
            --disable-replaygain \
            --disable-rtp \
            --disable-rtpmanager \
            --disable-rtsp \
            --disable-shapewipe \
            --disable-smpte \
            --disable-spectrum \
            --disable-udp \
            --disable-videobox \
            --disable-videocrop \
            --disable-videofilter \
            --disable-videomixer \
            --disable-wavenc \
            --disable-y4m \
            --disable-oss \
            --disable-oss4 \
            --disable-gst_v4l2 \
            --disable-x \
            --disable-aalib \
            --disable-aalibtest \
            --disable-cairo \
            --disable-flac \
            --disable-gdk_pixbuf \
            --disable-jack \
            --disable-jpeg \
            --disable-libcaca \
            --disable-libdv \
            --disable-libpng \
            --disable-pulse \
            --disable-dv1394 \
            --disable-shout2 \
            --disable-speex \
            --disable-taglib \
            --disable-vpx \
            --disable-wavpack

            make -j 10
            make install
        fi
        cd $source_dir
    fi

    #gst-plugins-bad
    if ! [ -d ${GST_PLUGINS_BAD_1_X} ]; then
        set_terminal_caption gst-plugins-bad1
        tar xf ${archives_dir}/${GST_PLUGINS_BAD_1_X}.tar.xz

        cd ${GST_PLUGINS_BAD_1_X}

        #if ["$TARGET" == "MT5800"]; then
        if [ "$GST_PLUGINS_BAD_1_X" == "gst-plugins-bad-1.6.4" ]; then
            patch -Np1 -i ${archives_dir}/gst-plugins-bad-1.6.4_h265parser_no_sps_pps_fix.patch
            echo "patch gst-plugins-bad-1.6.4_h265parser_no_sps_pps_fix"
        fi

        if [ $fetch_only -eq 0 ]; then
            ./configure ${AUTOCONF_FLAGS} ${GSTREAMER_FLAGS} \
            --disable-accurip \
            --disable-adpcmdec \
            --disable-adpcmenc \
            --disable-aiff \
            --disable-videoframe_audiolevel \
            --disable-asfmux \
            --disable-audiofxbad \
            --disable-audiomixer \
            --disable-compositor \
            --disable-audiovisualizers \
            --disable-autoconvert \
            --disable-bayer \
            --disable-camerabin2 \
            --disable-cdxaparse \
            --disable-coloreffects \
            --disable-dataurisrc \
            --disable-dccp \
            --disable-debugutils \
            --disable-dvbsuboverlay \
            --disable-dvdspu \
            --disable-faceoverlay \
            --disable-festival \
            --disable-fieldanalysis \
            --disable-freeverb \
            --disable-frei0r \
            --disable-gaudieffects \
            --disable-geometrictransform \
            --disable-gdp \
            --disable-hdvparse \
            --disable-id3tag \
            --disable-inter \
            --disable-interlace \
            --disable-ivtc \
            --disable-jp2kdecimator \
            --disable-jpegformat \
            --disable-librfb \
            --disable-midi \
            --disable-mpegtsmux \
            --disable-mpegpsmux \
            --disable-mve \
            --disable-mxf \
            --disable-netsim \
            --disable-nuvdemux \
            --disable-onvif \
            --disable-patchdetect \
            --disable-pcapparse \
            --disable-pnm \
            --disable-removesilence \
            --disable-sdi \
            --disable-sdp \
            --disable-segmentclip \
            --disable-siren \
            --disable-smooth \
            --disable-speed \
            --disable-subenc \
            --disable-stereo \
            --disable-tta \
            --disable-videofilters \
            --disable-videomeasure \
            --disable-videosignal \
            --disable-vmnc \
            --disable-y4m \
            --disable-yadif \
            --disable-winscreencap \
            --disable-winks \
            --disable-android_media \
            --disable-apple_media \
            --disable-bluez \
            --disable-avc \
            --disable-shm \
            --disable-vcd \
            --disable-opensles \
            --disable-uvch264 \
            --disable-nvenc \
            --disable-tinyalsa \
            --disable-assrender \
            --disable-voamrwbenc \
            --disable-voaacenc \
            --disable-apexsink \
            --disable-bs2b \
            --disable-bz2 \
            --disable-chromaprint \
            --disable-curl \
            --disable-dash \
            --disable-dc1394 \
            --disable-decklink \
            --disable-directfb \
            --disable-wayland \
            --disable-webp \
            --disable-daala \
            --disable-dts \
            --disable-resindvd \
            --disable-faac \
            --disable-faad \
            --disable-fbdev \
            --disable-flite \
            --disable-gsm \
            --disable-fluidsynth \
            --disable-kate \
            --disable-ladspa \
            --disable-lv2 \
            --disable-libde265 \
            --disable-libmms \
            --disable-srtp \
            --disable-dtls \
            --disable-linsys \
            --disable-modplug \
            --disable-mimic \
            --disable-mpeg2enc \
            --disable-mplex \
            --disable-musepack \
            --disable-nas \
            --disable-neon \
            --disable-ofa \
            --disable-openal \
            --disable-opencv \
            --disable-openexr \
            --disable-openh264 \
            --disable-openjpeg \
            --disable-openni2 \
            --disable-opus \
            --disable-pvr \
            --disable-rsvg \
            --disable-gl \
            --disable-gtk3 \
            --disable-qt \
            --disable-vulkan \
            --disable-libvisual \
            --disable-timidity \
            --disable-teletextdec \
            --disable-wildmidi \
            --disable-sdl \
            --disable-sdltest \
            --disable-smoothstreaming \
            --disable-sndfile \
            --disable-soundtouch \
            --disable-spc \
            --disable-gme \
            --disable-xvid \
            --disable-dvb \
            --disable-wininet \
            --disable-acm \
            --disable-vdpau \
            --disable-sbc \
            --disable-schro \
            --disable-zbar \
            --disable-rtmp \
            --disable-spandsp \
            --disable-sndio \
            --disable-hls \
            --disable-x265

            make -j 10
            make install
        fi
        cd $source_dir
    fi
fi

if [ $fetch_only -eq 0 ]; then
    cp ${archives_dir}/setup.sh ${GSTROOT}
fi

pushd ${GSTROOT}/..
if ! [ -f gstreamer-${version}-${TARGET}.tar.xz ]; then
    tar cfa gstreamer-${version}-${TARGET}.tar.xz gstreamer-${version}
fi
popd

if [ ! -z "$TVSDK_DIR" ]; then
  pushd ${GSTROOT}
  echo "none" > basepkg
  cd ..
  TC_CACHE_LOG_VERBOSITY=2  $TVSDK_DIR/build/tc_cache.sh  create  gstreamer-${version}  ${HOST}-gstreamer
  popd
fi
